<?php
/**
 * Add starthub options to the WordPress Customizer.
 *
 * @package Admin
 */

starthub_add_smart_action( 'customize_preview_init', 'starthub_do_enqueue_wp_customize_assets' );

/**
 * Enqueue starthub assets for the WordPress Customizer.
 *
 * @since 1.0.0
 */
function starthub_do_enqueue_wp_customize_assets() {

	wp_enqueue_script( 'starthub-wp-customize-preview', starthub_ADMIN_JS_URL . 'wp-customize-preview.js', array( 'jquery', 'customize-preview' ), starthub_VERSION, true );

}


starthub_add_smart_action( 'customize_register', 'starthub_do_register_wp_customize_options' );

/**
 * Add starthub options to the WordPress Customizer.
 *
 * @since 1.0.0
 */
function starthub_do_register_wp_customize_options() {

	$fields = array(
		array(
			'id' => 'starthub_logo_image',
			'label' => esc_html__( 'Logo Image', 'start-hub' ),
			'type' => 'WP_Customize_Image_Control',
			'transport' => 'refresh'
		)
	);

	starthub_register_wp_customize_options( $fields, 'title_tagline', array( 'title' => esc_html__( 'Branding', 'start-hub' ) ) );

	// Get layout option without default for the count.
	$options = starthub_get_layouts_for_options();

	// Only show the layout options if more than two layouts are registered.
	if ( count( $options ) > 2 ) {

		$fields = array(
			array(
				'id' => 'starthub_layout',
				'label' => esc_html__( 'Default Layout', 'start-hub' ),
				'type' => 'radio',
				'default' => starthub_get_default_layout(),
				'options' => $options,
				'transport' => 'refresh'
			)
		);

		starthub_register_wp_customize_options( $fields, 'starthub_layout', array( 'title' => esc_html__( 'Default Layout', 'start-hub' ), 'priority' => 1000 ) );

	}

	$fields = array(
		array(
			'id' => 'starthub_viewport_width_group',
			'label' => esc_html__( 'Viewport Width', 'start-hub' ),
			'type' => 'group',
			'fields' => array(
				array(
					'id' => 'starthub_enable_viewport_width',
					'type' => 'activation',
					'default' => false
				),
				array(
					'id' => 'starthub_viewport_width',
					'type' => 'slider',
					'default' => 1000,
					'min' => 300,
					'max' => 2500,
					'interval' => 10,
					'unit' => 'px'
				),
			)
		),
		array(
			'id' => 'starthub_viewport_height_group',
			'label' => esc_html__( 'Viewport Height', 'start-hub' ),
			'type' => 'group',
			'fields' => array(
				array(
					'id' => 'starthub_enable_viewport_height',
					'type' => 'activation',
					'default' => false
				),
				array(
					'id' => 'starthub_viewport_height',
					'type' => 'slider',
					'default' => 1000,
					'min' => 300,
					'max' => 2500,
					'interval' => 10,
					'unit' => 'px'
				),
			)
		)
	);

	starthub_register_wp_customize_options( $fields, 'starthub_preview', array( 'title' => esc_html__( 'Preview Tools', 'start-hub' ), 'priority' => 1010 ) );

}