<?php
/**
 * Options and Actions used by starthub Compiler.
 *
 * @ignore
 *
 * @package API\Compiler
 */
final class starthub_tt_Compiler_Options {

	/**
	 * Constructor.
	 */
	public function __construct() {

		add_action( 'admin_init', array( $this, 'register' ) );
		add_action( 'admin_init', array( $this, 'flush' ) , -1 );
		add_action( 'admin_notices', array( $this, 'admin_notice' ) );
		add_action( 'starthub_field_flush_cache', array( $this, 'option' ) );
		add_action( 'starthub_field_descriptionstarthub_tt_compile_all_styles_append_markup', array( $this, 'maybe_disable_style_notice' ) );
		add_action( 'starthub_field_descriptionstarthub_tt_compile_all_scripts_group_append_markup', array( $this, 'maybe_disable_scripts_notice' ) );

	}


	/**
	 * Register options.
	 */
	public function register() {

		$fields = array(
			array(
				'id' => 'starthub_compiler_items',
				'type' => 'flush_cache',
				'description' => esc_html__( 'Clear CSS and Javascript cached files. New cached versions will be compiled on page load.', 'start-hub' )
			)
		);

		// Add styles compiler option only if supported
		if ( starthub_get_component_support( 'wp_styles_compiler' ) )
			$fields = array_merge( $fields, array(
				array(
					'id' => 'starthub_compile_all_styles',
					'label' => false,
					'checkbox_label' => esc_html__( 'Compile all WordPress styles', 'start-hub' ),
					'type' => 'checkbox',
					'default' => false,
					'description' => esc_html__( 'Compile and cache all the CSS files that have been enqueued to the WordPress head.', 'start-hub' )
				)
			) );

		// Add scripts compiler option only if supported
		if ( starthub_get_component_support( 'wp_scripts_compiler' ) )
			$fields = array_merge( $fields, array(
				array(
					'id' => 'starthub_compile_all_scripts_group',
					'label' => esc_html__( 'Compile all WordPress scripts', 'start-hub' ),
					'type' => 'group',
					'fields' => array(
						array(
							'id' => 'starthub_compile_all_scripts',
							'type' => 'activation',
							'default' => false
						),
						array(
							'id' => 'starthub_compile_all_scripts_mode',
							'type' => 'select',
							'default' => array( 'aggressive' ),
							'attributes' => array( 'style' => 'margin: -3px 0 0 -8px;' ),
							'options' => array(
								'aggressive' => esc_html__( 'Aggressive', 'start-hub' ),
								'standard' => esc_html__( 'Standard', 'start-hub' )
							)
						),
					),
					'description' => esc_html__( 'Compile and cache all the Javascript files that have been enqueued to the WordPress head.<!--more-->JavaSript is outputted in the footer if the level is set to <strong>Aggressive</strong> and might conflict with some third party plugins which are not following WordPress standards.', 'start-hub' )
				)
			) );

		starthub_register_options( $fields, 'starthub_settings', 'compiler_options', array(
			'title' => esc_html__( 'Compiler options', 'start-hub' ),
			'context' => 'normal'
		) );

	}


	/**
	 * Flush images for all folders set.
	 */
	public function flush() {

		if ( !starthub_post( 'starthub_flush_compiler_cache' ) )
			return;

		starthub_remove_dir( starthub_get_compiler_dir() );

	}


	/**
	 * Cache cleaner notice.
	 */
	public function admin_notice() {

		if ( !starthub_post( 'starthub_flush_compiler_cache' ) )
			return;

		echo '<div id="message" class="updated"><p>' . esc_html__( 'Cache flushed successfully!', 'start-hub' ) . '</p></div>' . "\n";

	}


	/**
	 * Add button used to flush cache.
	 */
	public function option( $field ) {

		if ( $field['id'] !== 'starthub_compiler_items' )
			return;

		echo '<input type="submit" name="starthub_flush_compiler_cache" value="' . esc_html__( 'Flush assets cache', 'start-hub' ) . '" class="button-secondary" />';

	}


	/**
	 * Maybe show disabled notice.
	 */
	public function maybe_disable_style_notice() {

		if ( get_option( 'starthub_compile_all_styles' ) && starthub_tt_is_compiler_dev_mode() )
			echo '<br /><span>' . esc_html__( 'Styles are not compiled in development mode.', 'start-hub' ) . '</span>';

	}

	/**
	 * Maybe show disabled notice.
	 */
	public function maybe_disable_scripts_notice() {

		if ( get_option( 'starthub_compile_all_scripts' ) && starthub_tt_is_compiler_dev_mode() )
			echo '<br /><span>' . esc_html__( 'Scripts are not compiled in development mode.', 'start-hub' ) . '</span>';

	}

}

new starthub_tt_Compiler_Options();
