<?php
/**
 * starthub images options.
 *
 * @ignore
 *
 * @package API\Image
 */
final class starthub_tt_Image_Options {

	/**
	 * Constructor.
	 */
	public function __construct() {

		// Load in priority 15 so that we can check if other starthub metaboxes exists.
		add_action( 'admin_init', array( $this, 'register' ), 15 );
		add_action( 'admin_init', array( $this, 'flush' ) , -1 );
		add_action( 'admin_notices', array( $this, 'admin_notice' ) );
		add_action( 'starthub_field_flush_edited_images', array( $this, 'option' ) );

	}


	/**
	 * Register options.
	 */
	public function register() {

		global $wp_meta_boxes;

		$fields = array(
			array(
				'id' => 'starthub_edited_images_directories',
				'type' => 'flush_edited_images',
				'description' => esc_html__( 'Clear all edited images. New images will be created on page load.', 'start-hub' )
			)
		);

		starthub_register_options( $fields, 'starthub_settings', 'images_options', array(
			'title' => esc_html__( 'Images options', 'start-hub' ),
			'context' => starthub_get( 'starthub_settings', $wp_meta_boxes ) ? 'column' : 'normal' // Check of other starthub boxes.
		) );

	}


	/**
	 * Flush images for all folders set.
	 */
	public function flush() {

		if ( !starthub_post( 'starthub_flush_edited_images' ) )
			return;

		starthub_remove_dir( starthub_get_images_dir() );

	}


	/**
	 * Image editor notice notice.
	 */
	public function admin_notice() {

		if ( !starthub_post( 'starthub_flush_edited_images' ) )
			return;

		echo '<div id="message" class="updated"><p>' . esc_html__( 'Images flushed successfully!', 'start-hub' ) . '</p></div>' . "\n";

	}


	/**
	 * Add button used to flush images.
	 */
	public function option( $field ) {

		if ( $field['id'] !== 'starthub_edited_images_directories' )
			return;

		echo '<input type="submit" name="starthub_flush_edited_images" value="' . esc_html__( 'Flush images', 'start-hub' ) . '" class="button-secondary" />';

	}

}

new starthub_tt_Image_Options();
