<?php
/**
 * Handle the starthub Term Meta workflow.
 *
 * @ignore
 *
 * @package API\Term_meta
 */
final class starthub_tt_Term_Meta {

	/**
	 * Fields section.
	 *
	 * @type string
	 */
	private $section;

	/**
	 * Constructor.
	 */
	public function __construct( $section ) {

		$this->section = $section;
		$this->do_once();

		add_action( starthub_get( 'taxonomy' ). '_edit_form_fields', array( $this, 'fields' ) );

	}


	/**
	 * Trigger actions only once.
	 */
	private function do_once() {

		static $once = false;

		if ( !$once ) :

			add_action( starthub_get( 'taxonomy' ). '_edit_form', array( $this, 'nonce' ) );
			add_action( 'edit_term', array( $this, 'save' ) );
			add_action( 'delete_term', array( $this, 'delete' ), 10, 3 );

			$once = true;

		endif;

	}


	/**
	 * Post meta nonce.
	 */
	public function nonce( $tag ) {

		echo '<input type="hidden" name="starthub_term_meta_nonce" value="' . esc_attr( wp_create_nonce( 'starthub_term_meta_nonce' ) ) . '" />';

	}


	/**
	 * Fields content.
	 */
	public function fields( $tag ) {

		starthub_remove_action( 'starthub_field_label' );
		starthub_modify_action_hook( 'starthub_field_description', 'starthub_field_wrap_after_markup' );
		starthub_modify_markup( 'starthub_field_description', 'p' );
		starthub_add_attribute( 'starthub_field_description', 'class', 'description' );

		foreach ( starthub_get_fields( 'term_meta', $this->section ) as $field ) {

			echo '<tr class="form-field">';
				echo '<th scope="row">';
					starthub_field_label( $field );
				echo '</th>';
				echo '<td>';
					starthub_field( $field );
				echo '</td>';
			echo '</tr>';

		}

	}


	/**
	 * Save Term Meta.
	 */
	public function save( $term_id ) {

		if ( defined( 'DOING_AJAX' ) && DOING_AJAX )
			return $term_id;

		if ( !wp_verify_nonce( starthub_post( 'starthub_term_meta_nonce' ), 'starthub_term_meta_nonce' ) )
			return $term_id;

		if ( !$fields = starthub_post( 'starthub_fields' ) )
			return $term_id;

		foreach ( $fields as $field => $value )
			update_option( "starthub_term_{$term_id}_{$field}", stripslashes_deep( $value ) );

	}


	/**
	 * Delete Term Meta.
	 */
	public function delete( $term, $term_id, $taxonomy ) {

		global $wpdb;

		$wpdb->query( $wpdb->prepare(
			"DELETE FROM $wpdb->options WHERE option_name LIKE %s",
			"starthub_term_{$term_id}_%"
		) );

	}

}