<?php
/**
 * Add starthub assets.
 *
 * @package Assets
 */

starthub_add_smart_action( 'starthub_uikit_enqueue_scripts', 'starthub_enqueue_uikit_components', 5 );

/**
 * Enqueue UIKit components and starthub style.
 *
 * starthub style is enqueued with the UIKit components to have access to UIKit LESS variables.
 *
 * @since 1.0.0
 */
function starthub_enqueue_uikit_components() {

	$core = array(
		'base',
		'block',
		'grid',
		'article',
		'comment',
		'panel',
		'nav',
		'navbar',
		'subnav',
		'table',
		'breadcrumb',
		'pagination',
		'list',
		'form',
		'button',
		'badge',
		'alert',
		'dropdown',
		'offcanvas',
		'text',
		'utility',
		'icon'
	);

	starthub_uikit_enqueue_components( $core, 'core', false );

	// Include uikit default theme.
	starthub_uikit_enqueue_theme( 'default' );

	// Enqueue uikit overwrite theme folder.
	starthub_uikit_enqueue_theme( 'start-hub', starthub_ASSETS_PATH . 'less/uikit-overwrite' );

	// Add the theme style as a uikit fragment to have access to all the variables.
	starthub_compiler_add_fragment( 'uikit', starthub_ASSETS_PATH . 'less/style.less', 'less' );

	// Add the theme default style as a uikit fragment only if the theme supports it.
	if ( current_theme_supports( 'starthub-default-styling' ) )
		starthub_compiler_add_fragment( 'uikit', starthub_ASSETS_PATH . 'less/default.less', 'less' );

}


starthub_add_smart_action( 'wp_enqueue_scripts', 'starthub_enqueue_assets', 5 );

/**
 * Enqueue starthub assets.
 *
 * @since 1.0.0
 */
function starthub_enqueue_assets() {

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

}


starthub_add_smart_action( 'after_setup_theme', 'starthub_add_editor_assets' );

/**
 * Add starthub editor assets.
 *
 * @since 1.2.5
 */
function starthub_add_editor_assets() {

	add_editor_style( starthub_ASSETS_URL . 'css/editor' . starthub_MIN_CSS . '.css' );

}