<?php
/**
 * Version: 1.0.8
 * Prepare and initialize the starthub framework.
 *
 * @package Initialize
 */


add_action( 'starthub_init', 'starthub_define_constants', -1 );

/**
 * Define constants.
 *
 * @ignore
 */
function starthub_define_constants() {

	// Define version.
	define( 'starthub_VERSION', '1.3.1' );

	// Define paths.
	if ( !defined( 'starthub_THEME_PATH' ) )
		define( 'starthub_THEME_PATH', wp_normalize_path( trailingslashit( get_template_directory() ) ) );

	define( 'starthub_PATH', starthub_THEME_PATH . 'lib/' );
	define( 'starthub_API_PATH', starthub_PATH . 'api/' );
	define( 'starthub_ASSETS_PATH', starthub_PATH . 'assets/' );
	define( 'starthub_RENDER_PATH', starthub_PATH . 'render/' );
	define( 'starthub_TEMPLATES_PATH', starthub_PATH . 'templates/' );
	define( 'starthub_STRUCTURE_PATH', starthub_TEMPLATES_PATH . 'structure/' );
	define( 'starthub_FRAGMENTS_PATH', starthub_TEMPLATES_PATH . 'fragments/' );

	// Define urls.
	if ( !defined( 'starthub_THEME_URL' ) )
		define( 'starthub_THEME_URL', trailingslashit( get_template_directory_uri() ) );

	define( 'starthub_URL', starthub_THEME_URL . 'lib/' );
	define( 'starthub_API_URL', starthub_URL . 'api/' );
	define( 'starthub_ASSETS_URL', starthub_URL . 'assets/' );
	define( 'starthub_LESS_URL', starthub_ASSETS_URL . 'less/' );
	define( 'starthub_JS_URL', starthub_ASSETS_URL . 'js/' );
	define( 'starthub_IMAGE_URL', starthub_ASSETS_URL . 'images/' );

	// Define admin paths.
	define( 'starthub_ADMIN_PATH', starthub_PATH . 'admin/' );

	// Define admin url.
	define( 'starthub_ADMIN_URL', starthub_URL . 'admin/' );
	define( 'starthub_ADMIN_ASSETS_URL', starthub_ADMIN_URL . 'assets/' );
	define( 'starthub_ADMIN_JS_URL', starthub_ADMIN_ASSETS_URL . 'js/' );

}


add_action( 'starthub_init', 'starthub_load_dependencies', -1 );

/**
 * Load dependencies.
 *
 * @ignore
 */
function starthub_load_dependencies() {

        load_template( starthub_API_PATH . 'init.php', true );

	// Load the necessary starthub components.
	starthub_load_api_components( array(
		'actions',
		'html',
		'term-meta',
		'post-meta',
		'image',
		'wp-customize',
		'compiler',
		'uikit',
		'template',
		'layout',
		'widget'
	) );

	// Add third party styles and scripts compiler support.
	starthub_add_api_component_support( 'wp_styles_compiler' );
	starthub_add_api_component_support( 'wp_scripts_compiler' );

	/**
	 * Fires after starthub API loads.
	 *
	 * @since 1.0.0
	 */
	do_action( 'starthub_after_load_api' );

}


add_action( 'starthub_init', 'starthub_add_theme_support' );

/**
 * Add theme support.
 *
 * @ignore
 */
function starthub_add_theme_support() {

	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'menus' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
	add_theme_support( 'custom-header', array(
		'width' => 2000,
		'height' => 500,
		'flex-height' => true,
		'flex-width' => true,
		'header-text' => false
	) );

	// starthub specific.
	add_theme_support( 'offcanvas-menu' );
	add_theme_support( 'starthub-default-styling' );

}


add_action( 'starthub_init', 'starthub_includes' );

/**
 * Include framework files.
 *
 * @ignore
 */
function starthub_includes() {

    // Include admin.
    if ( is_admin() ) {
        load_template( starthub_ADMIN_PATH . 'options.php', true );
        load_template( starthub_ADMIN_PATH . 'updater.php', true );
    }

    // Include assets.
    load_template( starthub_ASSETS_PATH . 'assets.php', true );

    // Include customizer.
    if (is_customize_preview()) {
        load_template(starthub_ADMIN_PATH . 'wp-customize.php', true);
    }

    // Include renderers.
    load_template( starthub_RENDER_PATH . 'template-parts.php', true );
    load_template( starthub_RENDER_PATH . 'fragments.php', true );
    load_template( starthub_RENDER_PATH . 'widget-area.php', true );
    load_template( starthub_RENDER_PATH . 'walker.php', true );
    load_template( starthub_RENDER_PATH . 'menu.php', true );        

}

/**
 * Fires before starthub loads.
 *
 * @since 1.0.0
 */
do_action( 'starthub_before_init' );

	/**
	 * Load starthub framework.
	 *
	 * @since 1.0.0
	 */
	do_action( 'starthub_init' );

/**
 * Fires after starthub loads.
 *
 * @since 1.0.0
 */
do_action( 'starthub_after_init' );