<?php
/**
 * Loads starthub fragments.
 *
 * @package Render\Fragments
 */

// Filter.
starthub_add_smart_action( 'template_redirect', 'starthub_load_global_fragments', 1 );

/**
 * Load global fragments and dynamic views.
 *
 * @since 1.0.0
 *
 * @param string $template The template filename.
 *
 * @return string The template filename.
 */
function starthub_load_global_fragments() {

	starthub_load_fragment_file( 'breadcrumb' );
	starthub_load_fragment_file( 'footer' );
	starthub_load_fragment_file( 'header' );
	starthub_load_fragment_file( 'menu' );
	starthub_load_fragment_file( 'post-shortcodes' );
	starthub_load_fragment_file( 'post' );
	starthub_load_fragment_file( 'widget-area' );
	starthub_load_fragment_file( 'embed' );
	starthub_load_fragment_file( 'deprecated' );

}


// Filter.
starthub_add_smart_action( 'comments_template', 'starthub_load_comments_fragment' );

/**
 * Load comments fragments.
 *
 * The comments fragments only loads if comments are active to prevent unnecessary memory usage.
 *
 * @since 1.0.0
 *
 * @param string $template The template filename.
 *
 * @return string The template filename.
 */
function starthub_load_comments_fragment( $template ) {

	if ( empty( $template ) )
		return;

	starthub_load_fragment_file( 'comments' );

	return $template;

}


starthub_add_smart_action( 'dynamic_sidebar_before', 'starthub_load_widget_fragment', -1 );

/**
 * Load widget fragments.
 *
 * The widget fragments only loads if a sidebar is active to prevent unnecessary memory usage.
 *
 * @since 1.0.0
 *
 * @return bool True on success, false on failure.
 */
function starthub_load_widget_fragment() {

	return starthub_load_fragment_file( 'widget' );

}


starthub_add_smart_action( 'pre_get_search_form', 'starthub_load_search_form_fragment' );

/**
 * Load search form fragments.
 *
 * The search form fragments only loads if search is active to prevent unnecessary memory usage.
 *
 * @since 1.0.0
 *
 * @return bool True on success, false on failure.
 */
function starthub_load_search_form_fragment() {

	return starthub_load_fragment_file( 'searchform' );

}