<?php
/**
 * Sets up starthub's menus.
 *
 * @package Render\Menu
 */

starthub_add_smart_action( 'after_setup_theme', 'starthub_do_register_default_menu' );

/**
 * Register default menu.
 *
 * @since 1.0.0
 */
function starthub_do_register_default_menu() {

	// Stop here if a menu already exists.
	if ( wp_get_nav_menus() )
		return;

	// Set up default menu.
	wp_update_nav_menu_item(
		wp_create_nav_menu( esc_html__( 'Navigation', 'start-hub' ) ),
		0,
		array(
			'menu-item-title' =>  esc_html__( 'Home', 'start-hub' ),
			'menu-item-classes' => 'home',
			'menu-item-url' => esc_url(home_url( '/' )),
			'menu-item-status' => 'publish'
		)
	);

}


starthub_add_smart_action( 'after_setup_theme', 'starthub_do_register_nav_menus' );

/**
 * Register nav menus.
 *
 * @since 1.0.0
 */
function starthub_do_register_nav_menus() {

	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'start-hub' ),
	) );

}


// Filter.
starthub_add_smart_action( 'wp_nav_menu_args', 'starthub_modify_menu_args' );

/**
 * Modify wp_nav_menu arguments.
 *
 * This function converts the wp_nav_menu to UIKit format. It uses starthub custom walker and also makes
 * use of the starthub HTML API.
 *
 * @since 1.0.0
 *
 * @param array $args The wp_nav_menu arguments.
 *
 * @return array The modified wp_nav_menu arguments.
 */
function starthub_modify_menu_args( $args ) {

	// Get type.
	$type = starthub_get( 'starthub_type', $args );

	// Check if the menu is in a widget area and set the type accordingly if it is defined.
	if ( $widget_area_type = starthub_get_widget_area( 'starthub_type' ) )
		$type = ( $widget_area_type == 'stack' ) ? 'sidenav' : $widget_area_type;

	// Stop if it isn't a starthub menu.
	if ( !$type )
		return $args;

	// Default item wrap attributes.
	$attr = array(
		'id' => '%1$s',
		'class' => array( starthub_get( 'menu_class', $args ) )
	);

	// Add UIKit navbar item wrap attributes.
	if ( $type == 'navbar' )
		$attr['class'][] = 'uk-navbar-nav';

	// Add UIKit sidenav item wrap attributes.
	if ( $type == 'sidenav' ) {

		$attr['class'][] = 'uk-nav uk-nav-parent-icon uk-nav-side';
		$attr['data-uk-nav'] = '{multiple:true}';

	}

	// Add UIKit offcanvas item wrap attributes.
	if ( $type == 'offcanvas' ) {

		$attr['class'][] = 'uk-nav uk-nav-parent-icon uk-nav-offcanvas';
		$attr['data-uk-nav'] = '{multiple:true}';

	}

	// Implode to avoid empty spaces.
	$attr['class'] = implode( ' ', array_filter( $attr['class'] ) );

	// Set to null if empty to avoid outputing empty class html attribute.
	if ( !$attr['class'] )
		$attr['class'] = null;

	$location_subfilter = ( $location = starthub_get( 'theme_location', $args ) ) ? "[_{$location}]" : null;

	// Force starthub menu arguments.
	$force = array(
		'starthub_type' => $type,
		'items_wrap' => starthub_open_markup( "starthub_menu[_{$type}]{$location_subfilter}", 'ul', $attr, $args ) . '%3$s' . starthub_close_markup( "starthub_menu[_{$type}]{$location_subfilter}", 'ul', $args ),
	);

	// Allow walker overwrite.
	if ( !starthub_get( 'walker', $args ) )
		$args['walker'] = new starthub_tt_Walker_Nav_Menu;

	// Adapt level to walker depth.
	$force['starthub_start_level'] = ( $level = starthub_get( 'starthub_start_level', $args ) ) ? ( $level - 1 ) : 0;

	return array_merge( $args, $force );

}