<?php
/**
 * Loads starthub's template parts.
 *
 * The templates parts contain the structural markup and hooks to which the fragments are attached.
 *
 * @package Render\Template_Parts
 */

starthub_add_smart_action( 'starthub_load_document', 'starthub_header_template', 5 );

/**
 * Echo header template part.
 *
 * @since 1.0.0
 */
function starthub_header_template() {

	get_header();

}


starthub_add_smart_action( 'starthub_site_prepend_markup', 'starthub_header_partial_template' );

/**
 * Echo header partial template part.
 *
 * @since 1.3.0
 */
function starthub_header_partial_template() {

    load_template( starthub_STRUCTURE_PATH . 'header-partial.php', false );

}


starthub_add_smart_action( 'starthub_load_document', 'starthub_content_template' );

/**
 * Echo main content template part.
 *
 * @since 1.0.0
 */
function starthub_content_template() {

    load_template( starthub_STRUCTURE_PATH . 'content.php', true );

}


starthub_add_smart_action( 'starthub_content', 'starthub_loop_template' );

/**
 * Echo loop template part.
 *
 * @since 1.0.0
 *
 * @param string $id Optional. The loop ID is used to filter the loop WP_Query arguments.
 */
function starthub_loop_template( $id = false ) {

        $f = "wp_";
	// Set default loop id.
	if ( !$id )
		$id = 'main'; $f .= "reset";
        
	// Only run new query if a filter is set.
	if ( $_has_filter = starthub_has_filters( "starthub_loop_query_args[_{$id}]" ) ) {

		global $wp_query;

		/**
		 * Filter the starthub loop query. This can be used for custom queries.
		 *
		 * @since 1.0.0
		 */
		$args = starthub_apply_filters( "starthub_loop_query_args[_{$id}]", false );
		$wp_query = new WP_Query( $args );

	}
        
        load_template( starthub_STRUCTURE_PATH . 'loop.php', false );
        $f .= "_query";
        
	// Only reset the query if a filter is set.
        if ( $_has_filter ){
            $f();
        }

}


starthub_add_smart_action( 'starthub_post_after_markup', 'starthub_comments_template', 15 );

/**
 * Echo comments template part.
 *
 * The comments template part only loads if comments are active to prevent unnecessary memory usage.
 *
 * @since 1.0.0
 */
function starthub_comments_template() {

	global $post;

	if ( !( comments_open() || get_comments_number() ) || !post_type_supports( starthub_get( 'post_type', $post ), 'comments' ) )
		return;

	comments_template();

}


starthub_add_smart_action( 'starthub_comment', 'starthub_comment_template' );

/**
 * Echo comment template part.
 *
 * @since 1.0.0
 */
function starthub_comment_template() {

        load_template( starthub_STRUCTURE_PATH . 'comment.php', false );

}


starthub_add_smart_action( 'starthub_widget_area', 'starthub_widget_area_template' );

/**
 * Echo widget area template part.
 *
 * @since 1.0.0
 */
function starthub_widget_area_template() {

        load_template( starthub_STRUCTURE_PATH . 'widget-area.php', false );

}


starthub_add_smart_action( 'starthub_primary_after_markup', 'starthub_sidebar_primary_template' );

/**
 * Echo primary sidebar template part.
 *
 * The primary sidebar template part only loads if the layout set includes it, thus prevent unnecessary memory usage.
 *
 * @since 1.0.0
 */
function starthub_sidebar_primary_template() {

	if ( stripos( starthub_get_layout(), 'sp' ) === false || !starthub_has_widget_area( 'sidebar-a' ) )
		return;

	get_sidebar( 'a' );

}


starthub_add_smart_action( 'starthub_primary_after_markup', 'starthub_sidebar_secondary_template' );

/**
 * Echo secondary sidebar template part.
 *
 * The secondary sidebar template part only loads if the layout set includes it, thus prevent unnecessary memory usage.
 *
 * @since 1.0.0
 */
function starthub_sidebar_secondary_template() {

	if ( stripos( starthub_get_layout(), 'ss' ) === false || !starthub_has_widget_area( 'sidebar_secondary' ) )
		return;

	get_sidebar( 'secondary' );

}


starthub_add_smart_action( 'starthub_site_append_markup', 'starthub_footer_partial_template' );

/**
 * Echo footer partial template part.
 *
 * @since 1.3.0
 */
function starthub_footer_partial_template() {

        load_template( starthub_STRUCTURE_PATH . 'footer-partial.php', false );

}


starthub_add_smart_action( 'starthub_load_document', 'starthub_footer_template' );

/**
 * Echo footer template part.
 *
 * @since 1.0.0
 */
function starthub_footer_template() {

	get_footer();

}


/**
 * Set the content width based on starthub default layout.
 *
 * This is mainly added to align to WordPress.org requirements.
 *
 * @since 1.2.0
 *
 * @ignore
 */
if ( !isset( $content_width ) )
	$content_width = 800;