<?php
/**
 * Echo header fragments.
 *
 * @package Fragments\Header
 */

starthub_add_smart_action( 'starthub_head', 'starthub_head_meta', 0 );

/**
 * Echo head meta.
 *
 * @since 1.0.0
 */
function starthub_head_meta() {

	echo '<meta charset="' . get_bloginfo( 'charset' ) . '" />' . "\n";
	echo '<meta name="viewport" content="width=device-width, initial-scale=1" />' . "\n";

}


starthub_add_smart_action( 'wp_head', 'starthub_head_pingback' );

/**
 * Echo head pingback.
 *
 * @since 1.0.0
 */
function starthub_head_pingback() {

	echo '<link rel="pingback" href="' . get_bloginfo( 'pingback_url' ) . '">' . "\n";

}


starthub_add_smart_action( 'wp_head', 'starthub_header_image' );

/**
 * Print the header image css inline in the header.
 *
 * @since 1.0.0
 */
function starthub_header_image() {

	if ( !current_theme_supports( 'custom-header' ) || !( $header_image = get_header_image() ) || empty( $header_image ) )
		return;
}


starthub_add_smart_action( 'starthub_header', 'starthub_site_branding' );

/**
 * Echo header site branding.
 *
 * @since 1.0.0
 */
function starthub_site_branding() {

	echo starthub_open_markup( 'starthub_site_branding', 'div', array(
		'class' => 'tm-site-branding uk-float-left' . ( !get_bloginfo( 'description' ) ? ' uk-margin-small-top' : null ),
	) );

		echo starthub_open_markup( 'starthub_site_title_link', 'a', array(
			'href' => esc_url(home_url('/')), // Automatically escaped.
			'rel' => 'home'
		) );

			if ( $logo = get_theme_mod( 'starthub_logo_image', false ) )
				echo starthub_selfclose_markup( 'starthub_logo_image', 'img', array(
					'class' => 'tm-logo',
					'src' => $logo, // Automatically escaped.
					'alt' => get_bloginfo( 'name' ), // Automatically escaped.
				) );
			else
				echo starthub_output( 'starthub_site_title_text', get_bloginfo( 'name' ) );

		echo starthub_close_markup( 'starthub_site_title_link', 'a' );

	echo starthub_close_markup( 'starthub_site_branding', 'div' );

}


starthub_add_smart_action( 'starthub_site_branding_append_markup', 'starthub_site_title_tag' );

/**
 * Echo header site title tag.
 *
 * @since 1.0.0
 */
function starthub_site_title_tag() {

	// Stop here if there isn't a description.
	if ( !$description = get_bloginfo( 'description' ) )
		return;

	echo starthub_open_markup( 'starthub_site_title_tag', 'span', array(
		'class' => 'tm-site-title-tag uk-text-small uk-text-muted uk-display-block'
	) );

		echo starthub_output( 'starthub_site_title_tag_text', $description );

	echo starthub_close_markup( 'starthub_site_title_tag', 'span' );

}