<?php
/**
 * Echo menu fragments.
 *
 * @package Fragments\Menu
 */

starthub_add_smart_action( 'starthub_header', 'starthub_primary_menu', 15 );

/**
 * Echo primary menu.
 *
 * @since 1.0.0
 */
function starthub_primary_menu() {

	$nav_visibility = current_theme_supports( 'offcanvas-menu' ) ? 'uk-visible-large' : '';

	echo starthub_open_markup( 'starthub_primary_menu', 'nav', array(
		'class' => 'tm-primary-menu uk-float-right uk-navbar'
	) );

		/**
		 * Filter the primary menu arguments.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args Nav menu arguments.
		 */
		$args = apply_filters( 'starthub_primary_menu_args', array(
			'theme_location' => has_nav_menu( 'primary' ) ? 'primary' : '',
			'fallback_cb' => 'starthub_no_menu_notice',
			'container' => '',
			'menu_class' => $nav_visibility, // Automatically escaped.
			'echo' => false,
			'starthub_type' => 'navbar'
		) );

		// Navigation.
		echo starthub_output( 'starthub_primary_menu', wp_nav_menu( $args ) );

	echo starthub_close_markup( 'starthub_primary_menu', 'nav' );

}


starthub_add_smart_action( 'starthub_primary_menu_append_markup', 'starthub_primary_menu_offcanvas_button', 5 );

/**
 * Echo primary menu offcanvas button.
 *
 * @since 1.0.0
 */
function starthub_primary_menu_offcanvas_button() {

	if ( !current_theme_supports( 'offcanvas-menu' ) )
		return;

	echo starthub_open_markup( 'starthub_primary_menu_offcanvas_button', 'a', array(
		'href' => '#offcanvas_menu',
		'class' => 'uk-button uk-hidden-large',
		'data-uk-offcanvas' => ''
	) );

		echo starthub_open_markup( 'starthub_primary_menu_offcanvas_button_icon', 'i', array(
			'class' => 'uk-icon-navicon uk-margin-small-right',
		) );

		echo starthub_close_markup( 'starthub_primary_menu_offcanvas_button_icon', 'i' );

		echo starthub_output( 'starthub_offcanvas_menu_button', esc_html__( 'Menu', 'start-hub' ) );

	echo starthub_close_markup( 'starthub_primary_menu_offcanvas_button', 'a' );

}


starthub_add_smart_action( 'starthub_widget_area_offcanvas_bar_offcanvas_menu_prepend_markup', 'starthub_primary_offcanvas_menu' );

/**
 * Echo off-canvas primary menu.
 *
 * @since 1.0.0
 */
function starthub_primary_offcanvas_menu() {

	if ( !current_theme_supports( 'offcanvas-menu' ) )
		return;

	echo starthub_open_markup( 'starthub_primary_offcanvas_menu', 'nav', array(
		'class' => 'tm-primary-offcanvas-menu uk-margin uk-margin-top'
	) );

		/**
		 * Filter the off-canvas primary menu arguments.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args Off-canvas nav menu arguments.
		 */
		$args = apply_filters( 'starthub_primary_offcanvas_menu_args', array(
			'theme_location' => has_nav_menu( 'primary' ) ? 'primary' : '',
			'fallback_cb' => 'starthub_no_menu_notice',
			'container' => '',
			'echo' => false,
			'starthub_type' => 'offcanvas'
		) );

		echo starthub_output( 'starthub_primary_offcanvas_menu', wp_nav_menu( $args ) );

	echo starthub_close_markup( 'starthub_primary_offcanvas_menu', 'nav' );

}


/**
 * Echo no menu notice.
 *
 * @since 1.0.0
 */
function starthub_no_menu_notice() {

	echo starthub_open_markup( 'starthub_no_menu_notice', 'p', array( 'class' => 'uk-alert uk-alert-warning' ) );

		echo starthub_output( 'starthub_no_menu_notice_text', esc_html__( 'Whoops, your site does not have a menu!', 'start-hub' ) );

	echo starthub_close_markup( 'starthub_no_menu_notice', 'p' );

}