<?php
/**
 * Add post shortcodes.
 *
 * @package Fragments\Post_Shortcodes
 */

starthub_add_smart_action( 'starthub_post_meta_date', 'starthub_post_meta_date_shortcode' );

/**
 * Echo post meta date shortcode.
 *
 * @since 1.0.0
 */
function starthub_post_meta_date_shortcode() {

	echo starthub_output( 'starthub_post_meta_date_prefix', esc_html__( 'Posted on ', 'start-hub' ) );

	echo starthub_open_markup( 'starthub_post_meta_date', 'time', array(
		'datetime' => get_the_time( 'c' )
	) );

		echo starthub_output( 'starthub_post_meta_date_text', get_the_time( get_option( 'date_format' ) ) );

	echo starthub_close_markup( 'starthub_post_meta_date', 'time' );

}


starthub_add_smart_action( 'starthub_post_meta_author', 'starthub_post_meta_author_shortcode' );

/**
 * Echo post meta author shortcode.
 *
 * @since 1.0.0
 */
function starthub_post_meta_author_shortcode() {

	starthub_output( 'starthub_post_meta_author_prefix', esc_html__( 'By ', 'start-hub' ) ) ;

	echo starthub_open_markup( 'starthub_post_meta_author', 'a', array(
		'href' => get_author_posts_url( get_the_author_meta( 'ID' ) ), // Automatically escaped.
	) );

		echo starthub_output( 'starthub_post_meta_author_text', get_the_author() );

	echo starthub_close_markup( 'starthub_post_meta_author', 'a' );

}


starthub_add_smart_action( 'starthub_post_meta_comments', 'starthub_post_meta_comments_shortcode' );

/**
 * Echo post meta comments shortcode.
 *
 * @since 1.0.0
 */
function starthub_post_meta_comments_shortcode() {

	global $post;

	if ( post_password_required() || !comments_open() )
		return;

	$comments_number = (int) get_comments_number( $post->ID );

	if ( $comments_number < 1 )
		$comment_text = starthub_output( 'starthub_post_meta_empty_comment_text', esc_html__( 'Leave a comment', 'start-hub' ) );
	else if ( $comments_number === 1 )
		$comment_text = starthub_output( 'starthub_post_meta_comments_text_singular', esc_html__( '1 comment', 'start-hub' ) );
	else
		$comment_text = starthub_output( 'starthub_post_meta_comments_text_plurial', esc_html__( '%s comments', 'start-hub' ) );

	echo starthub_open_markup( 'starthub_post_meta_comments', 'a', array(
		'href' => get_comments_link() // Automatically escaped.
	) );

		printf( $comment_text, (int) get_comments_number( $post->ID ) );

	echo starthub_close_markup( 'starthub_post_meta_comments', 'a' );

}


starthub_add_smart_action( 'starthub_post_meta_tags', 'starthub_post_meta_tags_shortcode' );

/**
 * Echo post meta tags shortcode.
 *
 * @since 1.0.0
 */
function starthub_post_meta_tags_shortcode() {

	$tags = get_the_tag_list( null, ', ' );

	if ( !$tags || is_wp_error( $tags ) )
		return;

	echo starthub_output( 'starthub_post_meta_tags_prefix', esc_html__( 'Tagged with: ', 'start-hub' ) ) . $tags;

}


starthub_add_smart_action( 'starthub_post_meta_categories', 'starthub_post_meta_categories_shortcode' );

/**
 * Echo post meta categories shortcode.
 *
 * @since 1.0.0
 */
function starthub_post_meta_categories_shortcode() {

	$categories = get_the_category_list( ', ' );

	if ( !$categories || is_wp_error( $categories ) )
		return;

	echo starthub_output( 'starthub_post_meta_categories_prefix', esc_html__( 'Filed under: ', 'start-hub' ) ) . $categories;

}
