<?php
/**
 * Echo widget fragments.
 *
 * @package Fragments\Widget
 */

starthub_add_smart_action( 'starthub_widget', 'starthub_widget_badge', 5 );

/**
 * Echo widget badge.
 *
 * @since 1.0.0
 */
function starthub_widget_badge() {

	if ( !starthub_get_widget( 'badge' ) )
		return;

	echo starthub_open_markup( 'starthub_widget_badge' . starthub_tt_widget_subfilters(), 'div', 'class=uk-panel-badge uk-badge' );

		echo starthub_widget_shortcodes( starthub_get_widget( 'badge_content' ) );

	echo starthub_close_markup( 'starthub_widget_badge' . starthub_tt_widget_subfilters(), 'div' );

}


starthub_add_smart_action( 'starthub_widget', 'starthub_widget_title' );

/**
 * Echo widget title.
 *
 * @since 1.0.0
 */
function starthub_widget_title() {

	if ( !( $title = starthub_get_widget( 'title' ) ) || !starthub_get_widget( 'show_title' ) )
		return;

	echo starthub_open_markup( 'starthub_widget_title' . starthub_tt_widget_subfilters(), 'h3', 'class=uk-panel-title' );

		echo starthub_output( 'starthub_widget_title_text', $title );

	echo starthub_close_markup( 'starthub_widget_title' . starthub_tt_widget_subfilters(), 'h3' );

}


starthub_add_smart_action( 'starthub_widget', 'starthub_widget_content', 15 );

/**
 * Echo widget content.
 *
 * @since 1.0.0
 */
function starthub_widget_content() {

	echo starthub_open_markup( 'starthub_widget_content' . starthub_tt_widget_subfilters(), 'div' );

		echo starthub_output( 'starthub_widget_content' . starthub_tt_widget_subfilters(), starthub_get_widget( 'content' ) );

	echo starthub_close_markup( 'starthub_widget_content' . starthub_tt_widget_subfilters(), 'div' );

}


starthub_add_smart_action( 'starthub_no_widget', 'starthub_no_widget' );

/**
 * Echo no widget content.
 *
 * @since 1.0.0
 */
function starthub_no_widget() {

	// Only apply this notice to sidebar-a and sidebar_secondary.
	if ( !in_array( starthub_get_widget_area( 'id' ), array( 'sidebar-a', 'sidebar_secondary' ) ) )
		return;

	echo starthub_open_markup( 'starthub_no_widget_notice', 'p', array( 'class' => 'uk-alert uk-alert-warning' ) );

		echo starthub_output( 'starthub_no_widget_notice_text', sprintf( esc_html__( '%s does not have any widget assigned!', 'start-hub' ), starthub_get_widget_area( 'name' ) ) );

	echo starthub_close_markup( 'starthub_no_widget_notice', 'p' );

}

starthub_add_filter( 'starthub_widget_content_attributes', 'starthub_modify_widget_content_attributes' );

/**
 * Modify core widgets content attributes, so they use the default UIKit styling.
 *
 * @since 1.0.0
 *
 * @param array $attributes The current widget attributes.
 *
 * @return array The modified widget attributes.
 */
function starthub_modify_widget_content_attributes( $attributes ) {

	$type = starthub_get_widget( 'type' );

	$target = array(
		'archives',
		'categories',
		'links',
		'meta',
		'pages',
		'recent-posts',
		'recent-comments'
	);

	$current_class = isset( $attributes['class'] ) ? $attributes['class'] . ' ' : '';

	if ( in_array( starthub_get_widget( 'type' ), $target ) )
		$attributes['class'] = $current_class . 'uk-list'; // Automatically escaped.

	if ( $type == 'calendar' )
		$attributes['class'] = $current_class . 'uk-table uk-table-condensed'; // Automatically escaped.

	return $attributes;

}


starthub_add_filter( 'starthub_widget_content_categories_output', 'starthub_modify_widget_count' );
starthub_add_filter( 'starthub_widget_content_archives_output', 'starthub_modify_widget_count' );

/**
 * Modify widget count.
 *
 * @since 1.0.0
 *
 * @param string $content The widget content.
 *
 * @return string The modified widget content.
 */
function starthub_modify_widget_count( $content ) {

	$count = starthub_output( 'starthub_widget_count', '$1' );

	if ( starthub_get( 'dropdown', starthub_get_widget( 'options' ) ) == true ) {

		$output = $count;

	} else {

		$output = starthub_open_markup( 'starthub_widget_count', 'span', 'class=tm-count' );

			$output .= $count;

		$output .= starthub_close_markup( 'starthub_widget_count', 'span' );

	}

	// Keep closing tag to avoid overwriting the inline JavaScript.
	return preg_replace( '#>((\s|&nbsp;)\((.*)\))#', '>' . $output, $content );

}


starthub_add_filter( 'starthub_widget_content_categories_output', 'starthub_remove_widget_dropdown_label' );
starthub_add_filter( 'starthub_widget_content_archives_output', 'starthub_remove_widget_dropdown_label' );

/**
 * Modify widget dropdown label.
 *
 * @since 1.0.0
 *
 * @param string $content The widget content.
 *
 * @return string The modified widget content.
 */
function starthub_remove_widget_dropdown_label( $content ) {

	return preg_replace( '#<label([^>]*)class="screen-reader-text"(.*?)>(.*?)</label>#', '', $content ) ;

}