<?php
/**
 * Echo the posts loop structural markup. It also calls the loop action hooks.
 *
 * @package Structure\Loop
 */


/**
 * Fires before the loop.
 *
 * This hook fires even if no post exists.
 *
 * @since 1.0.0
 */
do_action( 'starthub_before_loop' );

	if ( have_posts() && !is_404() ) :

		/**
		 * Fires before posts loop.
		 *
		 * This hook fires if posts exist.
		 *
		 * @since 1.0.0
		 */
		do_action( 'starthub_before_posts_loop' );

		while ( have_posts() ) : the_post();

			$article_attributes = array(
				'id' => get_the_ID(), // Automatically escaped.
				'class' => implode( ' ', get_post_class( array( 'uk-article', ( current_theme_supports( 'starthub-default-styling' ) ? 'uk-panel-box' : null ) ) ) ) // Automatically escaped.
			);

			echo starthub_open_markup( 'starthub_post', 'article', $article_attributes );

				echo starthub_open_markup( 'starthub_post_header', 'header' );

					/**
					 * Fires in the post header.
					 *
					 * @since 1.0.0
					 */
					do_action( 'starthub_post_header' );

				echo starthub_close_markup( 'starthub_post_header', 'header' );

				echo starthub_open_markup( 'starthub_post_body', 'div' );

					/**
					 * Fires in the post body.
					 *
					 * @since 1.0.0
					 */
					do_action( 'starthub_post_body' );

				echo starthub_close_markup( 'starthub_post_body', 'div' );

			echo starthub_close_markup( 'starthub_post', 'article' );

		endwhile;

		/**
		 * Fires after the posts loop.
		 *
		 * This hook fires if posts exist.
		 *
		 * @since 1.0.0
		 */
		do_action( 'starthub_after_posts_loop' );

	else :

		/**
		 * Fires if no posts exist.
		 *
		 * @since 1.0.0
		 */
		do_action( 'starthub_no_post' );

	endif;

/**
 * Fires after the loop.
 *
 * This hook fires even if no post exists.
 *
 * @since 1.0.0
 */
do_action( 'starthub_after_loop' );
