<?php
/**
 * 
 * Start Hub - Creative Multi Concept Responsive WordPress Theme, exclusively on Envato Market: https://themeforest.net/user/torbara/portfolio?ref=torbara
 * @encoding     UTF-8
 * @copyright    Copyright (C) 2016 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Anatoly Chebotaryoff (anatolijchebotaryov@gmail.com)
 * @support      support@torbara.com
 * 
 */

class starthub_breadcrumbs extends \WP_Widget
{
    public function __construct()
    {
        $widget_ops = array('description' => 'Display your sites breadcrumb navigation');
        parent::__construct(false, 'Warp - Breadcrumbs', $widget_ops);
    }

    public function widget($args, $instance)
    {
        global $wp_query;

        extract($args);

        $title = $instance['title'];
        $home_title = trim($instance['home_title']);

        if (empty($home_title)) {
            $home_title = 'Home';
        }

        echo $before_widget;

        if ($title) {
            echo $before_title . $title . $after_title;
        }

        if (!is_home() && !is_front_page()) {

            $page_title = '<div class="uk-container uk-container-center uk-breadcrumbs-title"><div class="page-title">';
            
            $output = '<div class="uk-breadcrumbs-wrapper"><div class="uk-container uk-container-center"><ul class="uk-breadcrumb">';

            $output .= '<li><a href="'.esc_url(home_url('/')).'">'.esc_html($home_title).'</a></li>';

            if (is_single()) {
                if ($cats = get_the_category()) {
                    $cat = $cats[0];

                    if (is_object($cat)) {
                        if ($cat->parent != 0) {
                            $cats = explode("@@@", get_category_parents($cat->term_id, true, "@@@"));

                            unset($cats[count($cats)-1]);
                            $output .= str_replace('<li>@@','<li>', '<li>'.implode("</li><li>", $cats).'</li>');
                        } else {
                            $output .= '<li><a href="'.get_category_link($cat->term_id).'">'.esc_html($cat->name).'</a></li>';
                        }
                    }
                }
            }

            if (is_category()) {

                $cat_obj = $wp_query->get_queried_object();

                $cats = explode("@@@", get_category_parents($cat_obj->term_id, TRUE, '@@@'));

                unset($cats[count($cats)-1]);

                $cats[count($cats)-1] = '@@<span>'.strip_tags($cats[count($cats)-1]).'</span>';

                $output .= str_replace('<li>@@','<li class="uk-active">', '<li>'.implode("</li><li>", $cats).'</li>');
                $page_title .= str_replace('@@<span>','<span>', '<span>'.end($cats).'</span>');

            } elseif (is_tag()) {
                $output .= '<li class="uk-active"><span>'.single_cat_title('',false).'</span></li>';
                $page_title .= '<span>'.single_cat_title('',false).'</span>';
            } elseif (is_date()) {
                $output .= '<li class="uk-active"><span>'.single_month_title(' ',false).'</span></li>';
                $page_title .= '<span>'.single_month_title(' ',false).'</span>';
            } elseif (is_author()) {
                
                $user = !empty($wp_query->query_vars['author_name']) ? get_user_by("login", $wp_query->query_vars['author_name']) : get_user_by("id", ((int) $_GET['author']));

                $output .= '<li class="uk-active"><span>'.esc_html($user->display_name).'</span></li>';
                $page_title .= '<span>'.esc_html($user->display_name).'</span>';
            } elseif (is_search()) {
                $output .= '<li class="uk-active"><span>'.stripslashes(strip_tags(get_search_query())).'</span></li>';
                $page_title .= '<span>'.stripslashes(strip_tags(get_search_query())).'</span>';
            } elseif (is_tax()) {
                $taxonomy = get_taxonomy (get_query_var('taxonomy'));
                $term = get_query_var('term');
                $output .= '<li class="uk-active"><span>'.$taxonomy->label .': '.$term.'</span></li>';
                $page_title .= '<span>'.$taxonomy->label .': '.$term.'</span>';
            } elseif (is_archive()) {
                // woocommerce shop page
                if (is_plugin_active("woocommerce/woocommerce.php") && is_shop()) {
                    $title = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';
                    $output .= '<li class="uk-active"><span>'.esc_html($title).'</span></li>';
                    $page_title .= '<span>'.esc_html($title).'</span>';
                }
            } else {
                $ancestors = get_ancestors(get_the_ID(), 'page');
                for($i = count($ancestors)-1; $i >= 0; $i--) {
                    $output .= '<li><a href="'.get_page_link($ancestors[$i]).'" title="'.get_the_title($ancestors[$i]).'">'.get_the_title($ancestors[$i]).'</a></li>';
                }
                $output .= '<li class="uk-active"><span>'.get_the_title().'</span></li>';
                $page_title .= '<span>'.get_the_title().'</span>';
            }

            $page_title .= '</div></div>';
            
            $output .= '</ul></div></div>';

        } else {

            $output = '<ul class="uk-breadcrumb">';

            $output .= '<li class="uk-active"><span>'.esc_html($home_title).'</span></li>';

            $output .= '</ul>';

        }

        echo $page_title;
        
        echo $output;

        echo $after_widget;

    }

    public function update($new_instance, $old_instance)
    {
        return $new_instance;
    }

    public function form($instance)
    {
        $title = (isset($instance['title']) ? esc_attr($instance['title']) : '');
        $home_title = (isset($instance['home_title']) ? esc_attr($instance['home_title']) : '');
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')) ?>"><?php esc_html_e('Title:','start-hub') ?></label>
            <input type="text" name="<?php echo esc_attr($this->get_field_name('title')) ?>"  value="<?php echo esc_attr($title); ?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')) ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('home_title')) ?>"><?php esc_html_e('Home title:','start-hub') ?></label>
            <input type="text" placeholder="Home" name="<?php echo esc_attr($this->get_field_name('home_title')) ?>"  value="<?php echo esc_attr($home_title) ?>" class="widefat" id="<?php echo esc_attr($this->get_field_id('home_title')) ?>">
        </p>
        <?php
    }
}

register_widget('starthub_breadcrumbs');
